@@ -7,10 +7,11 @@
 #include <error.h>
 
 
-#define PROCFILES 2
+#define PROCFILES 3
 static char *procfiles[PROCFILES] = {
 	"/proc/acpi/ibm/light",
 	"/proc/acpi/asus/mled",
+	"/sys/class/leds/asus:phone/brightness",
 };
 
 int main(int argc, char* argv[]) {
@@ -20,7 +21,7 @@ int main(int argc, char* argv[]) {
 	for (i=0; i<PROCFILES; i++) {
 
 		if (stat(procfiles[i], &info) != 0) {
-			error (0,errno,"Could not stat procfile %s",procfiles[i]);
+			// error (0,errno,"Could not stat procfile %s",procfiles[i]);
 			continue;
 		}
 		
